@@ -1,6 +1,8 @@
+import tempfile
 import unittest
 
 import hazwaz
+import hazwaz.unittest
 
 
 class testEditorMixin(unittest.TestCase):
@@ -33,5 +35,27 @@ class testEditorMixin(unittest.TestCase):
         )
 
 
+class MyCommand(hazwaz.MainCommand, hazwaz.mixins.ExternalEditorMixin):
+    """
+    A command that edits a file
+    """
+
+    def main(self):
+        my_file = tempfile.NamedTemporaryFile()
+        self.edit_file_in_external_editor(my_file.name)
+        my_file.close()
+
+
+class testCommandWithMixin(hazwaz.unittest.HazwazTestCase):
+    def test_run(self):
+        cmd = MyCommand()
+        cmd.editors = [("true", "true")]
+        stream = self.run_with_argv(cmd, [
+            "mycommand",
+        ])
+        self.assertEqual(stream["stdout"].getvalue(), "")
+        self.assertEqual(stream["stderr"].getvalue(), "")
+
+
 if __name__ == '__main__':
     unittest.main()
